"""Implementation of Sentence Transformers model validated in MTEB."""

from mteb.model_meta import ModelMeta

all_MiniLM_L6_v2 = ModelMeta(
    name="sentence-transformers/all-MiniLM-L6-v2",
    languages=["eng-Latn"],
    open_source=True,
    revision="e4ce9877abf3edfe10b0d82785e83bdcb973e22e",
    release_date="2021-08-30",
)

paraphrase_multilingual_MiniLM_L12_v2 = ModelMeta(
    name="sentence-transformers/paraphrase-multilingual-MiniLM-L12-v2",
    languages=[
        "ara_Arab",
        "bul_Cyrl",
        "cat_Latn",
        "ces_Latn",
        "dan_Latn",
        "deu_Latn",
        "ell_Grek",
        "eng_Latn",
        "spa_Latn",
        "est_Latn",
        "fas_Arab",
        "fin_Latn",
        "fra_Latn",
        "fra_Latn",
        "glg_Latn",
        "guj_Gujr",
        "heb_Hebr",
        "hin_Deva",
        "hrv_Latn",
        "hun_Latn",
        "hye_Armn",
        "ind_Latn",
        "ita_Latn",
        "jpn_Jpan",
        "kat_Geor",
        "kor_Hang",
        "kur_Arab",
        "lit_Latn",
        "lav_Latn",
        "mkd_Cyrl",
        "mon_Cyrl",
        "mar_Deva",
        "msa_Latn",
        "mya_Mymr",
        "nob_Latn",
        "nld_Latn",
        "pol_Latn",
        "por_Latn",
        "por_Latn",
        "ron_Latn",
        "rus_Cyrl",
        "slk_Latn",
        "slv_Latn",
        "sqi_Latn",
        "srp_Cyrl",
        "swe_Latn",
        "tha_Thai",
        "tur_Latn",
        "ukr_Cyrl",
        "urd_Arab",
        "vie_Latn",
        "zho_Hans",
        "zho_Hant",
    ],
    open_source=True,
    revision="bf3bf13ab40c3157080a7ab344c831b9ad18b5eb",
    release_date="2019-11-01",  # release date of paper
)
